@@ -2,7 +2,7 @@
 import re
 from django.core.management import call_command
 
-from html5_appcache.cache import reset_cache_manifest, get_cached_manifest
+from html5_appcache.cache import reset_cache_manifest, get_cached_manifest, clear_cache_manifest
 from html5_appcache.models import GlobalPermission
 from html5_appcache.test_utils.base import BaseDataTestCase
 from html5_appcache.views import ManifestAppCache, CacheStatusView, ManifestUpdateView
@@ -17,48 +17,55 @@ class ManifestViewTest(BaseDataTestCase):
         cls.manifest_perm = GlobalPermission.objects.create(codename="can_update_manifest")
         super(ManifestViewTest, cls).setUpClass()
 
+    def setUp(self):
+        clear_cache_manifest()
+
     def test_manifest_version(self):
         request = self.get_request('/', user=self.admin)
-        view = ManifestAppCache.as_view()
-        response = view(request, appcache_update=1)
+        view = ManifestAppCache.as_view(appcache_update=1)
+        response = view(request)
         version = self.version_rx.findall(response.content)
         self.assertTrue(version)
         reset_cache_manifest()
-        response = view(request, appcache_update=1)
+        response = view(request)
         version2 = self.version_rx.findall(response.content)
         self.assertNotEqual(version, version2)
 
     def test_command_view_equivalent(self):
         request = self.get_request('/', user=self.admin)
-        view = ManifestAppCache.as_view()
-        response = view(request, appcache_update=1)
-        manifest_view = re.sub("# (date|version).+", "", response.content)
-        reset_cache_manifest()
+        view = ManifestAppCache.as_view(appcache_update=1)
+        response = view(request)
+        # version / date / comments removed as we're interested in
+        # extracted urls. stripped for the same reason
+        manifest_view = re.sub("# (date|version).+", "", response.content).strip()
+        clear_cache_manifest()
         call_command("update_manifest")
-        manifest_command = re.sub("# (date|version).+", "", get_cached_manifest())
+        # version / date / comments removed as we're interested in
+        # extracted urls. stripped for the same reason
+        manifest_command = re.sub("# (date|version).+", "", get_cached_manifest()).strip()
         self.assertEqual(manifest_command, manifest_view)
 
     def test_update_manifest_view_noauth(self):
         request = self.get_request('/')
         request.META['HTTP_X_REQUESTED_WITH'] = 'XMLHttpRequest'
-        view = ManifestUpdateView.as_view()
-        response = view(request, appcache_update=1)
+        view = ManifestUpdateView.as_view(appcache_update=1)
+        response = view(request)
         self.assertTrue(response.content.find('"success": false') > -1)
 
     def test_update_manifest_staff(self):
         self.user.user_permissions.add(self.manifest_perm)
         request = self.get_request('/', user=self.user)
         request.META['HTTP_X_REQUESTED_WITH'] = 'XMLHttpRequest'
-        view = ManifestUpdateView.as_view()
-        response = view(request, appcache_update=1)
+        view = ManifestUpdateView.as_view(appcache_update=1)
+        response = view(request)
         self.assertEqual(response.status_code, 200)
         self.assertTrue(response.content.find("OK") > -1)
         self.user.user_permissions.remove(self.manifest_perm)
 
         request = self.get_request('/', user=self.user)
         request.META['HTTP_X_REQUESTED_WITH'] = 'XMLHttpRequest'
-        view = ManifestUpdateView.as_view()
-        response = view(request, appcache_update=1)
+        view = ManifestUpdateView.as_view(appcache_update=1)
+        response = view(request)
         self.assertEqual(response.status_code, 200)
         self.assertTrue(response.content.find('"success": false') > -1)
 
